==> qt4-x11_4.6.3.orig.tar.gz: qt-everywhere-opensource-src-4.6.3/tools/assistant/tools/qhelpconverter/finishpage.cpp <==
/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Assistant of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtGui/QTextEdit>
#include <QtGui/QLayout>
#include <QtGui/QSpacerItem>
#include <QtGui/QApplication>

#include "finishpage.h"

QT_BEGIN_NAMESPACE

FinishPage::FinishPage(QWidget *parent)
    : QWizardPage(parent)
{
    setTitle(tr("Converting File"));
    setSubTitle(QLatin1String("Creating the new Qt help files from the "
        "old .adp file."));
    setFinalPage(true);

    QVBoxLayout *layout = new QVBoxLayout(this);
    layout->addItem(new QSpacerItem(20, 20, QSizePolicy::Minimum,
        QSizePolicy::Fixed));

    m_textEdit = new QTextEdit();
    layout->addWidget(m_textEdit);

    layout->addItem(new QSpacerItem(20, 40, QSizePolicy::Minimum,
        QSizePolicy::Expanding));
}

void FinishPage::appendMessage(const QString &msg)
{
    m_textEdit->append(msg);
    qApp->processEvents();
}

QT_END_NAMESPACE

==> qt4-x11_4.7.2.orig.tar.gz: qt-everywhere-opensource-src-4.7.2/tools/assistant/tools/qhelpconverter/finishpage.cpp <==
/****************************************************************************
**
** Copyright (C) 2011 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt Assistant of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

#include <QtGui/QTextEdit>
#include <QtGui/QLayout>
#include <QtGui/QSpacerItem>
#include <QtGui/QApplication>

#include "finishpage.h"

QT_BEGIN_NAMESPACE

FinishPage::FinishPage(QWidget *parent)
    : QWizardPage(parent)
{
    setTitle(tr("Converting File"));
    setSubTitle(tr("Creating the new Qt help files from the old ADP file."));
    setFinalPage(true);

    QVBoxLayout *layout = new QVBoxLayout(this);
    layout->addItem(new QSpacerItem(20, 20, QSizePolicy::Minimum,
        QSizePolicy::Fixed));

    m_textEdit = new QTextEdit();
    layout->addWidget(m_textEdit);

    layout->addItem(new QSpacerItem(20, 40, QSizePolicy::Minimum,
        QSizePolicy::Expanding));
}

void FinishPage::appendMessage(const QString &msg)
{
    m_textEdit->append(msg);
    qApp->processEvents();
}

QT_END_NAMESPACE
